using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

namespace ImageSharpApp.AlgProcessor.Forms
{
    partial class FilterNonLinUnsharpForm : Form
    {
        private bool userChanged = false;
        private FilterNonLinUnsharpParams pars = null;

        public FilterNonLinUnsharpParams Params
        {
            get
            {
                return this.pars;
            }
        }

        public FilterNonLinUnsharpForm(FilterNonLinUnsharpParams pars)
        {
            InitializeComponent();

            this.pars = pars;

            this.userChanged = false;
            trackBarSigma.Minimum = (int)(pars.SigmaRange.Min * numericUpDownSigma.DecimalPlaces * 10.0);
            trackBarSigma.Maximum = (int)(pars.SigmaRange.Max * numericUpDownSigma.DecimalPlaces * 10.0);
            trackBarSigma.Value = (int)(pars.Sigma * numericUpDownSigma.DecimalPlaces * 10.0);
            trackBarIntensity.Minimum = (int)(pars.IntensityRange.Min * numericUpDownIntensity.DecimalPlaces * 10.0);
            trackBarIntensity.Maximum = (int)(pars.IntensityRange.Max * numericUpDownIntensity.DecimalPlaces * 10.0);
            trackBarIntensity.Value = (int)(pars.Intensity * numericUpDownIntensity.DecimalPlaces * 10.0);
            trackBarSigma.TickStyle = TickStyle.None;
            trackBarIntensity.TickStyle = TickStyle.None;
            numericUpDownSigma.Minimum = (decimal)pars.SigmaRange.Min;
            numericUpDownSigma.Maximum = (decimal)pars.SigmaRange.Max;
            numericUpDownSigma.Value = (decimal)pars.Sigma;
            numericUpDownIntensity.Minimum = (decimal)pars.IntensityRange.Min;
            numericUpDownIntensity.Maximum = (decimal)pars.IntensityRange.Max;
            numericUpDownIntensity.Value = (decimal)pars.Intensity;
            this.userChanged = true;
        }

        public FilterNonLinUnsharpForm()
        {
            InitializeComponent();
        }

        private void trackBarSigma_ValueChanged(object sender, EventArgs e)
        {
            if (userChanged)
            {
                userChanged = false;
                double sigma = trackBarSigma.Value / (numericUpDownSigma.DecimalPlaces * 10.0);
                this.pars.Sigma = sigma;
                numericUpDownSigma.Value = (decimal)Math.Min(this.pars.SigmaRange.Max, Math.Max(this.pars.SigmaRange.Min, sigma));
                userChanged = true;
            }
        }

        private void numericUpDownSigma_ValueChanged(object sender, EventArgs e)
        {
            if (userChanged)
            {
                userChanged = false;
                double sigma = (double)numericUpDownSigma.Value;
                this.pars.Sigma = sigma;
                trackBarSigma.Value = (int)Math.Min(this.pars.SigmaRange.Max * numericUpDownSigma.DecimalPlaces * 10, Math.Max(this.pars.SigmaRange.Min * numericUpDownSigma.DecimalPlaces * 10, sigma * numericUpDownSigma.DecimalPlaces * 10));
                userChanged = true;
            }
        }

        private void trackBarIntensity_ValueChanged(object sender, EventArgs e)
        {
            if (userChanged)
            {
                userChanged = false;
                double intensity = trackBarIntensity.Value / (numericUpDownIntensity.DecimalPlaces * 10.0);
                this.pars.Intensity = intensity;
                numericUpDownIntensity.Value = (decimal)Math.Min(this.pars.IntensityRange.Max, Math.Max(this.pars.IntensityRange.Min, intensity));
                userChanged = true;
            }
        }

        private void numericUpDownIntensity_ValueChanged(object sender, EventArgs e)
        {
            if (userChanged)
            {
                userChanged = false;
                double intensity = (double)numericUpDownIntensity.Value;
                this.pars.Intensity = intensity;
                trackBarIntensity.Value = (int)Math.Min(this.pars.IntensityRange.Max * numericUpDownIntensity.DecimalPlaces * 10, Math.Max(this.pars.IntensityRange.Min * numericUpDownIntensity.DecimalPlaces * 10, intensity * numericUpDownIntensity.DecimalPlaces * 10));
                userChanged = true;
            }
        }

        private void buttonOK_Click(object sender, EventArgs e)
        {
            this.DialogResult = DialogResult.OK;
            this.Dispose();
        }

        private void buttonCancel_Click(object sender, EventArgs e)
        {
            this.DialogResult = DialogResult.Cancel;
            this.Dispose();
        }
    }
}