using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

namespace ImageSharpApp.AlgProcessor.Forms
{
    partial class FilterSpectralBandpassForm : Form
    {
        private bool userChanged = false;
        private FilterSpectralBandpassParams pars = null;

        public FilterSpectralBandpassParams Params
        {
            get
            {
                return this.pars;
            }
        }

        public FilterSpectralBandpassForm(FilterSpectralBandpassParams pars)
        {
            InitializeComponent();

            this.pars = pars;

            this.userChanged = false;
            trackBarMin.Minimum = pars.MinRange.Min;
            trackBarMin.Maximum = pars.MinRange.Max;
            trackBarMin.Value = pars.Min;
            trackBarMax.Minimum = pars.MaxRange.Min;
            trackBarMax.Maximum = pars.MaxRange.Max;
            trackBarMax.Value = pars.Max;
            trackBarMin.TickStyle = TickStyle.None;
            trackBarMax.TickStyle = TickStyle.None;
            numericUpDownMin.Minimum = pars.MinRange.Min;
            numericUpDownMin.Maximum = pars.MinRange.Max;
            numericUpDownMin.Value = pars.Min;
            numericUpDownMax.Minimum = pars.MaxRange.Min;
            numericUpDownMax.Maximum = pars.MaxRange.Max;
            numericUpDownMax.Value = pars.Max;
            this.userChanged = true;
        }

        public FilterSpectralBandpassForm()
        {
            InitializeComponent();
        }

        private void trackBarMin_ValueChanged(object sender, EventArgs e)
        {
            if (userChanged)
            {
                userChanged = false;
                int val = trackBarMin.Value;
                this.pars.Min = val;
                numericUpDownMin.Value = Math.Min(this.pars.MinRange.Max, Math.Max(this.pars.MinRange.Min, val));
                userChanged = true;
            }
        }

        private void trackBarMax_ValueChanged(object sender, EventArgs e)
        {
            if (userChanged)
            {
                userChanged = false;
                int val = trackBarMax.Value;
                this.pars.Max = val;
                numericUpDownMax.Value = Math.Min(this.pars.MaxRange.Max, Math.Max(this.pars.MaxRange.Min, val));
                userChanged = true;
            }
        }

        private void numericUpDownMin_ValueChanged(object sender, EventArgs e)
        {
            if (userChanged)
            {
                userChanged = false;
                int val = (int)numericUpDownMin.Value;
                this.pars.Min = val;
                trackBarMin.Value = Math.Min(this.pars.MinRange.Max, Math.Max(this.pars.MinRange.Min, val));
                userChanged = true;
            }
        }

        private void numericUpDownMax_ValueChanged(object sender, EventArgs e)
        {
            if (userChanged)
            {
                userChanged = false;
                int val = (int)numericUpDownMax.Value;
                this.pars.Max = val;
                trackBarMax.Value = Math.Min(this.pars.MaxRange.Max, Math.Max(this.pars.MaxRange.Min, val));
                userChanged = true;
            }
        }

        private void buttonOK_Click(object sender, EventArgs e)
        {
            this.DialogResult = DialogResult.OK;
            this.Dispose();
        }

        private void buttonCancel_Click(object sender, EventArgs e)
        {
            this.DialogResult = DialogResult.Cancel;
            this.Dispose();
        }
    }
}