using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

namespace ImageSharpApp.AlgProcessor.Forms
{
    partial class FilterSpectralSmoothBandpassForm : Form
    {
        private bool userChanged = false;
        private FilterSpectralSmoothBandpassParams pars = null;

        public FilterSpectralSmoothBandpassParams Params
        {
            get
            {
                return this.pars;
            }
        }

        public FilterSpectralSmoothBandpassForm(FilterSpectralSmoothBandpassParams pars)
        {
            InitializeComponent();

            this.pars = pars;

            this.userChanged = false;
            trackBarMin.Minimum = pars.MinRange.Min;
            trackBarMin.Maximum = pars.MinRange.Max;
            trackBarMin.Value = pars.Min;
            trackBarMax.Minimum = pars.MaxRange.Min;
            trackBarMax.Maximum = pars.MaxRange.Max;
            trackBarMax.Value = pars.Max;
            trackBarMinSmooth.Minimum = pars.Omega1Range.Min;
            trackBarMinSmooth.Maximum = pars.Omega1Range.Max;
            trackBarMinSmooth.Value = pars.Omega1;
            trackBarMaxSmooth.Minimum = pars.Omega2Range.Min;
            trackBarMaxSmooth.Maximum = pars.Omega2Range.Max;
            trackBarMaxSmooth.Value = pars.Omega2;
            trackBarMin.TickStyle = TickStyle.None;
            trackBarMax.TickStyle = TickStyle.None;
            trackBarMinSmooth.TickStyle = TickStyle.None;
            trackBarMaxSmooth.TickStyle = TickStyle.None;
            numericUpDownMin.Minimum = pars.MinRange.Min;
            numericUpDownMin.Maximum = pars.MinRange.Max;
            numericUpDownMin.Value = pars.Min;
            numericUpDownMax.Minimum = pars.MaxRange.Min;
            numericUpDownMax.Maximum = pars.MaxRange.Max;
            numericUpDownMax.Value = pars.Max;
            numericUpDownMinSmooth.Minimum = pars.Omega1Range.Min;
            numericUpDownMinSmooth.Maximum = pars.Omega1Range.Max;
            numericUpDownMinSmooth.Value = pars.Omega1;
            numericUpDownMaxSmooth.Minimum = pars.Omega2Range.Min;
            numericUpDownMaxSmooth.Maximum = pars.Omega2Range.Max;
            numericUpDownMaxSmooth.Value = pars.Omega2;
            this.userChanged = true;
        }

        public FilterSpectralSmoothBandpassForm()
        {
            InitializeComponent();
        }

        private void trackBarMin_ValueChanged(object sender, EventArgs e)
        {
            if (userChanged)
            {
                userChanged = false;
                int val = trackBarMin.Value;
                this.pars.Min = val;
                numericUpDownMin.Value = Math.Min(this.pars.MinRange.Max, Math.Max(this.pars.MinRange.Min, val));
                userChanged = true;
            }
        }

        private void trackBarMax_ValueChanged(object sender, EventArgs e)
        {
            if (userChanged)
            {
                userChanged = false;
                int val = trackBarMax.Value;
                this.pars.Max = val;
                numericUpDownMax.Value = Math.Min(this.pars.MaxRange.Max, Math.Max(this.pars.MaxRange.Min, val));
                userChanged = true;
            }
        }

        private void numericUpDownMin_ValueChanged(object sender, EventArgs e)
        {
            if (userChanged)
            {
                userChanged = false;
                int val = (int)numericUpDownMin.Value;
                this.pars.Min = val;
                trackBarMin.Value = Math.Min(this.pars.MinRange.Max, Math.Max(this.pars.MinRange.Min, val));
                userChanged = true;
            }
        }

        private void numericUpDownMax_ValueChanged(object sender, EventArgs e)
        {
            if (userChanged)
            {
                userChanged = false;
                int val = (int)numericUpDownMax.Value;
                this.pars.Max = val;
                trackBarMax.Value = Math.Min(this.pars.MaxRange.Max, Math.Max(this.pars.MaxRange.Min, val));
                userChanged = true;
            }
        }

        private void trackBarMinSmooth_ValueChanged(object sender, EventArgs e)
        {
            if (userChanged)
            {
                userChanged = false;
                int val = trackBarMinSmooth.Value;
                this.pars.Omega1 = val;
                numericUpDownMinSmooth.Value = Math.Min(this.pars.Omega1Range.Max, Math.Max(this.pars.Omega1Range.Min, val));
                userChanged = true;
            }
        }

        private void trackBarMaxSmooth_ValueChanged(object sender, EventArgs e)
        {
            if (userChanged)
            {
                userChanged = false;
                int val = trackBarMaxSmooth.Value;
                this.pars.Omega2 = val;
                numericUpDownMaxSmooth.Value = Math.Min(this.pars.Omega2Range.Max, Math.Max(this.pars.Omega2Range.Min, val));
                userChanged = true;
            }
        }

        private void numericUpDownMinSmooth_ValueChanged(object sender, EventArgs e)
        {
            if (userChanged)
            {
                userChanged = false;
                int val = (int)numericUpDownMinSmooth.Value;
                this.pars.Omega1 = val;
                trackBarMinSmooth.Value = Math.Min(this.pars.Omega1Range.Max, Math.Max(this.pars.Omega1Range.Min, val));
                userChanged = true;
            }
        }

        private void numericUpDownMaxSmooth_ValueChanged(object sender, EventArgs e)
        {
            if (userChanged)
            {
                userChanged = false;
                int val = (int)numericUpDownMaxSmooth.Value;
                this.pars.Omega2 = val;
                trackBarMaxSmooth.Value = Math.Min(this.pars.Omega2Range.Max, Math.Max(this.pars.Omega2Range.Min, val));
                userChanged = true;
            }
        }

        private void buttonOK_Click(object sender, EventArgs e)
        {
            this.DialogResult = DialogResult.OK;
            this.Dispose();
        }

        private void buttonCancel_Click(object sender, EventArgs e)
        {
            this.DialogResult = DialogResult.Cancel;
            this.Dispose();
        }
    }
}