using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

namespace ImageSharpApp.AlgProcessor.Forms
{
    partial class FilterSpectralSmoothLowpassForm : Form
    {
        private bool userChanged = false;
        private FilterSpectralSmoothLowpassParams pars = null;

        public FilterSpectralSmoothLowpassParams Params
        {
            get
            {
                return this.pars;
            }
        }

        public FilterSpectralSmoothLowpassForm(FilterSpectralSmoothLowpassParams pars)
        {
            InitializeComponent();

            this.pars = pars;

            this.userChanged = false;
            trackBarCutoff.Minimum = pars.CutoffRange.Min;
            trackBarCutoff.Maximum = pars.CutoffRange.Max;
            trackBarCutoff.Value = pars.Cutoff;
            trackBarCutoffSmooth.Minimum = pars.OmegaRange.Min;
            trackBarCutoffSmooth.Maximum = pars.OmegaRange.Max;
            trackBarCutoffSmooth.Value = pars.Omega;
            trackBarCutoff.TickStyle = TickStyle.None;
            trackBarCutoffSmooth.TickStyle = TickStyle.None;
            numericUpDownCutoff.Minimum = pars.CutoffRange.Min;
            numericUpDownCutoff.Maximum = pars.CutoffRange.Max;
            numericUpDownCutoff.Value = pars.Cutoff;
            numericUpDownCutoffSmooth.Minimum = pars.OmegaRange.Min;
            numericUpDownCutoffSmooth.Maximum = pars.OmegaRange.Max;
            numericUpDownCutoffSmooth.Value = pars.Omega;
            this.userChanged = true;
        }

        public FilterSpectralSmoothLowpassForm()
        {
            InitializeComponent();
        }

        private void trackBarCutoff_ValueChanged(object sender, EventArgs e)
        {
            if (userChanged)
            {
                userChanged = false;
                int val = trackBarCutoff.Value;
                this.pars.Cutoff = val;
                numericUpDownCutoff.Value = Math.Min(this.pars.CutoffRange.Max, Math.Max(this.pars.CutoffRange.Min, val));
                userChanged = true;
            }
        }

        private void numericUpDownCutoff_ValueChanged(object sender, EventArgs e)
        {
            if (userChanged)
            {
                userChanged = false;
                int val = (int)numericUpDownCutoff.Value;
                this.pars.Cutoff = val;
                trackBarCutoff.Value = Math.Min(this.pars.CutoffRange.Max, Math.Max(this.pars.CutoffRange.Min, val));
                userChanged = true;
            }
        }

        private void trackBarCutoffSmooth_ValueChanged(object sender, EventArgs e)
        {
            if (userChanged)
            {
                userChanged = false;
                int val = trackBarCutoffSmooth.Value;
                this.pars.Omega = val;
                numericUpDownCutoffSmooth.Value = Math.Min(this.pars.OmegaRange.Max, Math.Max(this.pars.OmegaRange.Min, val));
                userChanged = true;
            }
        }

        private void numericUpDownCutoffSmooth_ValueChanged(object sender, EventArgs e)
        {
            if (userChanged)
            {
                userChanged = false;
                int val = (int)numericUpDownCutoffSmooth.Value;
                this.pars.Omega = val;
                trackBarCutoffSmooth.Value = Math.Min(this.pars.OmegaRange.Max, Math.Max(this.pars.OmegaRange.Min, val));
                userChanged = true;
            }
        }

        private void buttonOK_Click(object sender, EventArgs e)
        {
            this.DialogResult = DialogResult.OK;
            this.Dispose();
        }

        private void buttonCancel_Click(object sender, EventArgs e)
        {
            this.DialogResult = DialogResult.Cancel;
            this.Dispose();
        }
    }
}