using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

namespace ImageSharpApp.AlgProcessor.Forms
{
    partial class GeoSeamCarvingForm : Form
    {
        private bool userChanged = false;
        private bool adaptRatio = true;
        private GeoSeamCarvingParams pars = null;
        private int oheight = 0;
        private int owidth = 0;

        public GeoSeamCarvingParams Params
        {
            get
            {
                return this.pars;
            }
        }

        public GeoSeamCarvingForm(GeoSeamCarvingParams pars, int width, int height)
        {
            InitializeComponent();

            this.pars = pars;
            this.owidth = width;
            this.oheight = height;

            this.userChanged = false;
            groupBoxParams.Text = "Rescale image (original: "+width+" x "+height+" px)";
            trackBarWidth.Minimum = pars.NWidthRange.Min * 100 / width;
            trackBarWidth.Maximum = pars.NWidthRange.Max * 100 / width;
            trackBarWidth.Value = 100;
            trackBarHeight.Minimum = pars.NHeightRange.Min * 100 / height;
            trackBarHeight.Maximum = pars.NHeightRange.Max * 100 / height;
            trackBarHeight.Value = 100;
            trackBarWidth.TickStyle = TickStyle.None;
            trackBarHeight.TickStyle = TickStyle.None;
            numericUpDownWidth.Minimum = pars.NWidthRange.Min;
            numericUpDownWidth.Maximum = pars.NWidthRange.Max;
            numericUpDownWidth.Value = width;
            numericUpDownHeight.Minimum = pars.NHeightRange.Min;
            numericUpDownHeight.Maximum = pars.NHeightRange.Max;
            numericUpDownHeight.Value = height;
            this.userChanged = true;
        }

        public GeoSeamCarvingForm()
        {
            InitializeComponent();
        }

        private void trackBarWidth_ValueChanged(object sender, EventArgs e)
        {
            if (userChanged)
            {
                userChanged = false;
                int perc = trackBarWidth.Value;
                int nwidth = this.owidth * perc / 100;
                this.pars.NWidth = nwidth;
                numericUpDownWidth.Value = Math.Min(this.pars.NWidthRange.Max, Math.Max(this.pars.NWidthRange.Min, nwidth));
                userChanged = true;
                if (adaptRatio && checkBoxAspectRatio.Checked)
                {
                    adaptRatio = false;
                    trackBarHeight.Value = perc;
                    adaptRatio = true;
                }
            }
        }

        private void trackBarHeight_ValueChanged(object sender, EventArgs e)
        {
            if (userChanged)
            {
                userChanged = false;
                int perc = trackBarHeight.Value;
                int nheight = this.oheight * perc / 100;
                this.pars.NHeight = nheight;
                numericUpDownHeight.Value = Math.Min(this.pars.NHeightRange.Max, Math.Max(this.pars.NHeightRange.Min, nheight));
                userChanged = true;
                if (adaptRatio && checkBoxAspectRatio.Checked)
                {
                    adaptRatio = false;
                    trackBarWidth.Value = perc;
                    adaptRatio = true;
                }
            }
        }

        private void numericUpDownWidth_ValueChanged(object sender, EventArgs e)
        {
            if (userChanged)
            {
                userChanged = false;
                int nwidth = (int)numericUpDownWidth.Value;
                int perc = nwidth * 100 / this.owidth;
                this.pars.NWidth = nwidth;
                int minp = this.pars.NWidthRange.Min * 100 / this.owidth;
                int maxp = this.pars.NWidthRange.Max * 100 / this.owidth;
                trackBarWidth.Value = Math.Min(maxp, Math.Max(minp, perc));
                userChanged = true;
                if (adaptRatio && checkBoxAspectRatio.Checked)
                {
                    adaptRatio = false;
                    trackBarHeight.Value = perc;
                    adaptRatio = true;
                }
            }
        }

        private void numericUpDownHeight_ValueChanged(object sender, EventArgs e)
        {
            if (userChanged)
            {
                userChanged = false;
                int nheight = (int)numericUpDownHeight.Value;
                int perc = nheight * 100 / this.oheight;
                this.pars.NHeight = nheight;
                int minp = this.pars.NHeightRange.Min * 100 / this.oheight;
                int maxp = this.pars.NHeightRange.Max * 100 / this.oheight;
                trackBarHeight.Value = Math.Min(maxp, Math.Max(minp, perc));
                userChanged = true;
                if (adaptRatio && checkBoxAspectRatio.Checked)
                {
                    adaptRatio = false;
                    trackBarWidth.Value = perc;
                    adaptRatio = true;
                }
            }
        }

        private void checkBoxAspectRatio_CheckedChanged(object sender, EventArgs e)
        {
            if (userChanged && checkBoxAspectRatio.Checked)
            {
                userChanged = false;
                int nwidth = (int)numericUpDownWidth.Value;
                int perc = this.owidth * 100 / nwidth;
                userChanged = true;
                trackBarHeight.Value = perc;
            }
        }

        private void buttonOK_Click(object sender, EventArgs e)
        {
            this.DialogResult = DialogResult.OK;
            this.Dispose();
        }

        private void buttonCancel_Click(object sender, EventArgs e)
        {
            this.DialogResult = DialogResult.Cancel;
            this.Dispose();
        }
    }
}