using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.Collections;
using ImageSharp.Images;

namespace ImageSharpApp
{
    partial class FormImage : Form
    {
        private IImage img = null;
        private ArrayList imgList = new ArrayList();
        private ProcessController controller = null;

        public IImage Img
        {
            get
            {
                return this.img;
            }
        }

        public ArrayList ImgList
        {
            get
            {
                return this.imgList;
            }
        }

        public ProcessController Controller
        {
            get
            {
                return this.controller;
            }
        }

        public void ShowImage()
        {
            this.imageBox.Image = this.img.ToBitmap();
        }

        public void FitFormToImage()
        {
            this.Height += this.img.Height - imageBox.Height;
            this.Width += this.img.Width - imageBox.Width;
        }

        public void AddImgCloneToList()
        {
            if (this.imgList.Contains(this.img))
            {
                this.img = this.img.Clone();
            }
            else
            {
                this.imgList.Add(this.img.Clone());
            }
        }

        public bool RestoreLastImgFromList()
        {
            int index = this.imgList.IndexOf(this.img);
            if (index != -1)
            {
                if (index > 0)
                {
                    this.img = this.imgList.ToArray()[index - 1] as IImage;
                    ShowImage();
                    return true;
                }
                else
                {
                    return false;
                }
            }
            else
            {
                IImage imgTemp = this.img;
                this.img = this.imgList.ToArray()[this.imgList.Count-1] as IImage;
                this.imgList.Add(imgTemp);
                ShowImage();
                return true;
            }
        }

        public bool RestoreNextImgFromList()
        {
            int index = this.imgList.IndexOf(this.img);
            if (index != -1)
            {
                if (index < imgList.Count - 1)
                {
                    this.img = this.imgList.ToArray()[index + 1] as IImage;
                    ShowImage();
                    if (index + 1 == imgList.Count - 1)
                    {
                        this.imgList.Remove(this.img);
                    }
                    return true;
                }
                else
                {
                    return false;
                }
            }
            else
            {
                return false;
            }
        }

        public void CutImgListOff()
        {
            if (this.imgList != null)
            {
                int index = this.imgList.IndexOf(this.img);
                if (index > -1 && index < imgList.Count - 1)
                {
                    this.imgList.RemoveRange(index + 1, imgList.Count - index - 1);
                }
            }
        }

        public FormImage(IImage img)
        {
            InitializeComponent();
            this.img = img;
            FitFormToImage();
            ShowImage();

            this.controller = new ProcessController(this);
        }

        public void MakeGrayImg()
        {
            if(this.img is ImageColor)
                this.img = new ImageGray((ImageColor)this.img);
            else if(this.img is ImageComplex)
                this.img = new ImageGray((ImageComplex)this.img);
            ShowImage();
        }
    }
}