using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.Collections;
using ImageSharp.Images;

namespace ImageSharpApp
{
    public partial class FormImgProc : Form
    {
        public FormImgProc()
        {
            InitializeComponent();
            activateImgControls(false);
            activateUndoControls(false);
            activateRedoControls(false);

            linearToolStripMenuItem.Enabled = false;
            croppingToolStripMenuItem.Enabled = false;
            rotationToolStripMenuItem.Enabled = false;
            cameraCalibrationToolStripMenuItem.Enabled = false;
            arithmeticsToolStripMenuItem.Enabled = false;
            medianToolStripMenuItem.Enabled = false;
            morphologicalFiltersToolStripMenuItem.Enabled = false;
            houghTransformToolStripMenuItem.Enabled = false;
            cornerDetectionToolStripMenuItem.Enabled = false;
            helpToolStripMenuItem1.Enabled = false;
            aboutToolStripMenuItem.Enabled = false;
            projectPageToolStripMenuItem.Enabled = false;
            userdefinedToolStripMenuItem.Enabled = false;
        }

        private void openImageToolStripMenuItem_Click(object sender, EventArgs e)
        {
            if (openImgDialog.ShowDialog() == DialogResult.OK)
            {
                try
                {
                    Bitmap bmp = new Bitmap(openImgDialog.FileName);
                    FormImage form = new FormImage(new ImageColor(bmp));
                    form.MdiParent = this;
                    form.Text = openImgDialog.FileName;
                    form.Show();
                    activateImgControls(true);
                }
                catch (Exception exc)
                {
                    MessageBox.Show("Image could not be loaded:\n\n" + exc.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                }
            }
        }

        private void saveImageToolStripMenuItem_Click(object sender, EventArgs e)
        {
            if ((FormImage)this.ActiveMdiChild != null && saveImageDialog.ShowDialog() == DialogResult.OK)
            {
                try
                {
                    ((FormImage)this.ActiveMdiChild).Img.ToBitmap().Save(saveImageDialog.FileName);
                }
                catch (Exception exc)
                {
                    MessageBox.Show("Image could not be saved:\n\n" + exc.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                }
            }
        }

        private void FormImgProc_MdiChildActivate(object sender, EventArgs e)
        {
            if (this.ActiveMdiChild != null)
            {
                FormImage form = (FormImage)this.ActiveMdiChild as FormImage;
                if (form.ImgList.Count > 1)
                {
                    int index = form.ImgList.IndexOf(form.Img);
                    if (index > -1)
                    {
                        if (index == 0)
                        {
                            activateUndoControls(false);
                            activateRedoControls(true);
                        }
                        else if (index == form.ImgList.Count - 1)
                        {
                            activateUndoControls(true);
                            activateRedoControls(false);
                        }
                        else
                        {
                            activateUndoControls(true);
                            activateRedoControls(true);
                        }
                    }
                    else
                    {
                        activateUndoControls(true);
                        activateRedoControls(false);
                    }
                }
                else
                {
                    activateUndoControls(false);
                    activateRedoControls(false);
                }
            }
            else
            {
                activateImgControls(false);
            }
        }

        private void activateImgControls(bool activate)
        {
            editToolStripMenuItem.Enabled = activate;
            geometricToolStripMenuItem.Enabled = activate;
            grayvalueTransformsToolStripMenuItem.Enabled = activate;
            filteringToolStripMenuItem.Enabled = activate;
            segmentationToolStripMenuItem.Enabled = activate;
            detectionToolStripMenuItem.Enabled = activate;
            saveImageToolStripMenuItem.Enabled = activate;
            toolStripSaveImage.Enabled = activate;
        }

        private void activateUndoControls(bool activate)
        {
            undoToolStripMenuItem.Enabled = activate;
            toolStripUndo.Enabled = activate;
        }

        private void activateRedoControls(bool activate)
        {
            redoToolStripMenuItem.Enabled = activate;
            toolStripRedo.Enabled = activate;
        }

        private void quitToolStripMenuItem_Click(object sender, EventArgs e)
        {
            this.Dispose();
        }

        private void toolStripOpenImage_Click(object sender, EventArgs e)
        {
            openImageToolStripMenuItem_Click(sender, e);
        }

        private void toolStripSaveImage_Click(object sender, EventArgs e)
        {
            saveImageToolStripMenuItem_Click(sender, e);
        }

        private void undoToolStripMenuItem_Click(object sender, EventArgs e)
        {
            if (this.ActiveMdiChild != null)
            {
                FormImage form = ((FormImage)this.ActiveMdiChild);
                if (form.RestoreLastImgFromList())
                {
                    activateRedoControls(true);
                }
                if (form.ImgList != null && form.ImgList.Count > 0 && form.Img == form.ImgList.ToArray()[0])
                {
                    activateUndoControls(false);
                }
            }
        }

        private void redoToolStripMenuItem_Click(object sender, EventArgs e)
        {
            if (this.ActiveMdiChild != null)
            {
                FormImage form = ((FormImage)this.ActiveMdiChild);
                if (form.RestoreNextImgFromList())
                {
                    activateUndoControls(true);
                }
                if (form.ImgList != null && !form.ImgList.Contains(form.Img))
                {
                    activateRedoControls(false);
                }
            }
        }

        private void toolStripUndo_Click(object sender, EventArgs e)
        {
            undoToolStripMenuItem_Click(sender, e);
        }

        private void toolStripRedo_Click(object sender, EventArgs e)
        {
            redoToolStripMenuItem_Click(sender, e);
        }

        private void doImageProcessing(IPAlgorithms algo)
        {
            if (this.ActiveMdiChild != null)
            {
                ((FormImage)this.ActiveMdiChild).Controller.Process(algo);
                if (((FormImage)this.ActiveMdiChild).ImgList.Count > 0)
                {
                    activateUndoControls(true);
                    activateRedoControls(false);
                }
            }
        }

        private void seamCarvingToolStripMenuItem_Click(object sender, EventArgs e)
        {
            doImageProcessing(IPAlgorithms.GeoSeamCarving);
        }

        private void croppingToolStripMenuItem_Click(object sender, EventArgs e)
        {

        }

        private void rotationToolStripMenuItem_Click(object sender, EventArgs e)
        {

        }

        private void calibrateCameraToolStripMenuItem_Click(object sender, EventArgs e)
        {

        }

        private void imageToWorldCoordinatesToolStripMenuItem_Click(object sender, EventArgs e)
        {

        }

        private void worldToImageCoordinatesToolStripMenuItem_Click(object sender, EventArgs e)
        {

        }

        private void arithmeticsToolStripMenuItem_Click(object sender, EventArgs e)
        {

        }

        private void contrastadaptionToolStripMenuItem_Click(object sender, EventArgs e)
        {
            doImageProcessing(IPAlgorithms.GrayContrastAdapt);
        }

        private void contraststretchingToolStripMenuItem_Click(object sender, EventArgs e)
        {
            doImageProcessing(IPAlgorithms.GrayContrastStretch);
        }

        private void gammaCorrectionToolStripMenuItem1_Click(object sender, EventArgs e)
        {
            doImageProcessing(IPAlgorithms.GrayGammaCorrection);
        }

        private void applyLUTToolStripMenuItem_Click(object sender, EventArgs e)
        {
            doImageProcessing(IPAlgorithms.GrayLUTApplication);
        }

        private void applytransformationFunctionToolStripMenuItem_Click(object sender, EventArgs e)
        {
            doImageProcessing(IPAlgorithms.GrayFunctionApplication);
        }

        private void imageInversionToolStripMenuItem_Click(object sender, EventArgs e)
        {
            doImageProcessing(IPAlgorithms.GrayImgInversion);
        }

        private void equalizationToolStripMenuItem_Click(object sender, EventArgs e)
        {
            doImageProcessing(IPAlgorithms.GrayHistEqualization);
        }

        private void localEqualizationToolStripMenuItem_Click(object sender, EventArgs e)
        {
            doImageProcessing(IPAlgorithms.GrayHistLocalEqualization);
        }

        private void specificationToolStripMenuItem_Click(object sender, EventArgs e)
        {
            doImageProcessing(IPAlgorithms.GrayHistSpecification);
        }

        private void thresholdingToolStripMenuItem_Click(object sender, EventArgs e)
        {
            doImageProcessing(IPAlgorithms.SegThresholding);
        }

        private void otsuThresholdingToolStripMenuItem_Click(object sender, EventArgs e)
        {
            doImageProcessing(IPAlgorithms.SegOtsuThresholding);
        }

        private void adaptiveDocumentBinarizationToolStripMenuItem_Click(object sender, EventArgs e)
        {
            doImageProcessing(IPAlgorithms.SegADB);
        }

        private void houghTransformToolStripMenuItem_Click(object sender, EventArgs e)
        {

        }

        private void gaussToolStripMenuItem_Click(object sender, EventArgs e)
        {
            doImageProcessing(IPAlgorithms.FilterLinearGauss);
        }

        private void adaptiveGaussToolStripMenuItem_Click(object sender, EventArgs e)
        {
            doImageProcessing(IPAlgorithms.FilterLinearAdaptiveGauss);
        }

        private void lowpassToolStripMenuItem_Click(object sender, EventArgs e)
        {
            doImageProcessing(IPAlgorithms.FilterLinearLowpass);
        }

        private void highpassToolStripMenuItem_Click(object sender, EventArgs e)
        {
            doImageProcessing(IPAlgorithms.FilterLinearHighpass);
        }

        private void highboostToolStripMenuItem_Click(object sender, EventArgs e)
        {
            doImageProcessing(IPAlgorithms.FilterLinearHighboost);
        }

        private void laplacianToolStripMenuItem_Click(object sender, EventArgs e)
        {
            doImageProcessing(IPAlgorithms.FilterLinearLaplacian);
        }

        private void laplacianSharpenToolStripMenuItem_Click(object sender, EventArgs e)
        {
            doImageProcessing(IPAlgorithms.FilterLinearLaplacianSharpen);
        }

        private void userdefinedToolStripMenuItem_Click(object sender, EventArgs e)
        {
            doImageProcessing(IPAlgorithms.FilterLinearUserDefined);
        }

        private void medianToolStripMenuItem_Click(object sender, EventArgs e)
        {
            doImageProcessing(IPAlgorithms.FilterNonLinearMedian);
        }

        private void isefToolStripMenuItem_Click(object sender, EventArgs e)
        {
            doImageProcessing(IPAlgorithms.FilterNonLinearISEF);
        }

        private void unsharpMaskingToolStripMenuItem_Click(object sender, EventArgs e)
        {
            doImageProcessing(IPAlgorithms.FilterNonLinearUnsharpen);
        }

        private void highboostToolStripMenuItem1_Click(object sender, EventArgs e)
        {
            doImageProcessing(IPAlgorithms.FilterNonLinearHighboost);
        }

        private void highboost2ToolStripMenuItem_Click(object sender, EventArgs e)
        {
            doImageProcessing(IPAlgorithms.FilterNonLinearHighboost2);
        }

        private void laplaceToolStripMenuItem1_Click(object sender, EventArgs e)
        {
            doImageProcessing(IPAlgorithms.FilterSpectralLaplace);
        }

        private void laplacianOfGaussianLoGToolStripMenuItem_Click(object sender, EventArgs e)
        {
            doImageProcessing(IPAlgorithms.FilterSpectralLoG);
        }

        private void bandpassToolStripMenuItem_Click(object sender, EventArgs e)
        {
            doImageProcessing(IPAlgorithms.FilterSpectralBandpass);
        }

        private void lowpassToolStripMenuItem1_Click(object sender, EventArgs e)
        {
            doImageProcessing(IPAlgorithms.FilterSpectralLowpass);
        }

        private void highpassToolStripMenuItem1_Click(object sender, EventArgs e)
        {
            doImageProcessing(IPAlgorithms.FilterSpectralHighpass);
        }

        private void smoothBandpassToolStripMenuItem_Click(object sender, EventArgs e)
        {
            doImageProcessing(IPAlgorithms.FilterSpectralSmoothBandpass);
        }

        private void smoothLowpassToolStripMenuItem_Click(object sender, EventArgs e)
        {
            doImageProcessing(IPAlgorithms.FilterSpectralSmoothLowpass);
        }

        private void smoothHighpassToolStripMenuItem_Click(object sender, EventArgs e)
        {
            doImageProcessing(IPAlgorithms.FilterSpectralSmoothHighpass);
        }

        private void calculateFourierImageToolStripMenuItem_Click(object sender, EventArgs e)
        {
            if (this.ActiveMdiChild != null)
            {
                IImage iimg = ((FormImage)this.ActiveMdiChild).Img;
                ImageComplex img = null;
                if (iimg is ImageGray)
                {
                    img = new ImageComplex(iimg as ImageGray);
                }
                else if (iimg is ImageColor)
                {
                    ImageGray imgGray = new ImageGray(iimg as ImageColor);
                    img = new ImageComplex(imgGray);
                }
                else
                {
                    img = iimg as ImageComplex;
                }

                if (img.Fmode == false)
                {
                    img.MakeForwardFourierTransform();
                    FormImage form = new FormImage(img);
                    form.MdiParent = this;
                    form.Text = ((FormImage)this.ActiveMdiChild).Text + " - Spectral";
                    form.Show();
                }
            }
        }

        private void cannyToolStripMenuItem_Click(object sender, EventArgs e)
        {
            doImageProcessing(IPAlgorithms.EdgesCanny);
        }

        private void shenCastanToolStripMenuItem_Click(object sender, EventArgs e)
        {
            doImageProcessing(IPAlgorithms.EdgesShenCastan);
        }

        private void marrHildrethToolStripMenuItem_Click(object sender, EventArgs e)
        {
            doImageProcessing(IPAlgorithms.EdgesMarrHildreth);
        }

        private void robertsToolStripMenuItem_Click(object sender, EventArgs e)
        {
            doImageProcessing(IPAlgorithms.EdgesRoberts);
        }

        private void prewittToolStripMenuItem_Click(object sender, EventArgs e)
        {
            doImageProcessing(IPAlgorithms.EdgesPrewitt);
        }

        private void sobelToolStripMenuItem_Click(object sender, EventArgs e)
        {
            doImageProcessing(IPAlgorithms.EdgesSobel);
        }

        private void laplaceToolStripMenuItem_Click(object sender, EventArgs e)
        {
            doImageProcessing(IPAlgorithms.EdgesLaplace);
        }

        private void linesToolStripMenuItem_Click(object sender, EventArgs e)
        {

        }

        private void circlesToolStripMenuItem_Click(object sender, EventArgs e)
        {

        }

        private void harrisToolStripMenuItem_Click(object sender, EventArgs e)
        {

        }
    }
}