﻿using System;
using System.Drawing;
using ImageSharp.Maths;

namespace ImageSharp.Images
{
    interface IPixelData
    {

    }
    
    /// <summary>
    /// Klasse zur Speicherung von RGB-Daten eines Pixels. Benötigt für den Zugriff auf die einzelnen Werte
    /// eines Bitmap-Objekts.
    /// </summary>
    struct RGBData : IPixelData
    {
        #region Öffentliche Attribute
        /// <summary>
        /// Blauwertanteil.
        /// </summary>
        public byte B;

        /// <summary>
        /// Grünanteil.
        /// </summary>
        public byte G;

        /// <summary>
        /// Rotanteil.
        /// </summary>
        public byte R;

        /// <summary>
        /// Alphaanteil (Luminanz).
        /// </summary>
        public byte A;
        #endregion

        public RGBData(byte r, byte g, byte b, byte a)
        {
            this.R = r;
            this.G = g;
            this.B = b;
            this.A = a;
        }
    };

    /// <summary>
    /// Klasse zur Speicherung von Grauwert-Daten eines Pixels.
    /// </summary>
    class GrayData : IPixelData, IComparable<byte>, IEquatable<byte>

    {
        #region Öffentliche Attribute
        /// <summary>
        /// Grauwert.
        /// </summary>
        public byte Value = 0;
        #endregion

        public GrayData() { }
        public GrayData(byte g)
        {
            this.Value = g;
        }

        #region interface implementations
        public int CompareTo(byte other)
        {
            return this.Value.CompareTo(other);
        }

        public bool Equals(byte other)
        {
            return this.Value.Equals(other);
        }
        #endregion
    }

    /// <summary>
    /// Klasse zur Speicherung von komplexen Daten eines Pixels.
    /// </summary>
    class ComplexData : IPixelData, IComparable<Complex>, IEquatable<Complex>
    {
        #region Öffentliche Attribute
        /// <summary>
        /// Komplexwert.
        /// </summary>
        public Complex Value;
        #endregion

        public ComplexData() { }
        public ComplexData(Complex c)
        {
            this.Value = c;
        }

        #region interface implementations
        public int CompareTo(Complex other)
        {
            return this.Value.CompareTo(other);
        }

        public bool Equals(Complex other)
        {
            return this.Value.Equals(other);
        }
        #endregion
    }

    interface IImage
    {
        int Height { get; }
        int Width { get; }

        IPixelData GetValueAt(int x, int y);
        void SetValueAt(int x, int y, IPixelData value);

        unsafe Bitmap ToBitmap();
        IImage Clone();
        void CopyFrom(IImage img);
    }
}
